==> opensearch-dashboards-2.9.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/core/server/opensearch/default_headers.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DEFAULT_HEADERS = void 0;

var _std = require("@osd/std");

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const DEFAULT_HEADERS = (0, _std.deepFreeze)({
  // OpenSearch uses this to identify when a request is coming from OpenSearch Dashboards, to allow OpenSearch Dashboards to
  // access system indices using the standard OpenSearch APIs without logging a warning. After migrating to
  // use the new system index APIs, this header can be removed.
  'x-opensearch-product-origin': 'opensearch-dashboards'
});
exports.DEFAULT_HEADERS = DEFAULT_HEADERS;

==> opensearch-dashboards-3.5.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/core/server/opensearch/default_headers.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDefaultHeaders = exports.DEFAULT_HEADERS = void 0;
var _std = require("@osd/std");
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const DEFAULT_HEADERS = exports.DEFAULT_HEADERS = (0, _std.deepFreeze)({
  // OpenSearch uses this to identify when a request is coming from OpenSearch Dashboards, to allow OpenSearch Dashboards to
  // access system indices using the standard OpenSearch APIs without logging a warning. After migrating to
  // use the new system index APIs, this header can be removed.
  'x-opensearch-product-origin': 'opensearch-dashboards'
});

/**
 * Returns default headers with optional compression header based on config.
 * @param requestCompression Whether to request compressed responses from OpenSearch.
 */
const getDefaultHeaders = (requestCompression = false) => {
  if (requestCompression) {
    return {
      ...DEFAULT_HEADERS,
      // Request compressed responses from OpenSearch to reduce payload size and improve query latency.
      'accept-encoding': 'gzip, deflate'
    };
  }
  return {
    ...DEFAULT_HEADERS
  };
};
exports.getDefaultHeaders = getDefaultHeaders;
